// SPDX-FileCopyrightText: 2025 Helmholtz-Zentrum hereon GmbH
//
// SPDX-License-Identifier: Apache-2.0

import Form from '@rjsf/mui';
import { IChangeEvent } from '@rjsf/core';
import { RJSFSchema, UiSchema } from '@rjsf/utils';
import validator from '@rjsf/validator-ajv8';

import { FormEvent } from 'react';

const log = (type: string) => console.log.bind(console, type);

function FunctionForm({
  schema,
  uiSchema,
  onSubmit,
  onError,
  onChange,
}: {
  schema?: RJSFSchema;
  uiSchema?: UiSchema;
  onSubmit?: ({ formData }: IChangeEvent, _event: FormEvent) => void;
  onError?: () => void;
  onChange?: ({ formData }: IChangeEvent, id: string | undefined) => void;
}) {
  if (typeof uiSchema === 'undefined') {
    uiSchema = {};
  }
  uiSchema.func_name = { 'ui:widget': 'hidden' };
  Object.entries(schema.properties).forEach(([prop, attrs]) => {
    // @ts-expect-error:next-line
    if (attrs.is_reporter) {
      uiSchema[prop] = { 'ui:widget': 'hidden' };
    }
  });
  return (
    <>
      <Form
        schema={schema}
        uiSchema={uiSchema}
        validator={validator}
        onSubmit={typeof onSubmit !== 'undefined' ? onSubmit : log('submitted')}
        onError={typeof onError !== 'undefined' ? onError : log('errors')}
        onChange={onChange}
      />
    </>
  );
}

export default FunctionForm;
