// SPDX-FileCopyrightText: 2025 Helmholtz-Zentrum hereon GmbH
//
// SPDX-License-Identifier: Apache-2.0

import r2wc from '@r2wc/react-to-web-component';
import FunctionContainer from './components/FunctionContainer.tsx';
import ClassContainer from './components/ClassContainer.tsx';
import ModuleContainer from './components/ModuleContainer.tsx';

const WebFunctionContainer = r2wc(FunctionContainer, {
  props: {
    schemaElement: 'string',
    schema: 'json',
    uiSchema: 'json',
    connection: 'function',
    websocketUrl: 'string',
    topic: 'string',
    outputDescription: 'string',
    functionName: 'string',
    skipDefaultResponseHandler: 'boolean',
    skipDefaultResponseHandlerCheck: 'function',
    skipDefaultErrorHandler: 'boolean',
    skipDefaultErrorHandlerCheck: 'function',
    skipDefaultProgressHandler: 'boolean',
    skipDefaultProgressHandlerCheck: 'function',
    constructorData: 'json',
  },
  events: {
    onResponse: {},
    onError: {},
    onProgress: {},
  },
});

const WebClassContainer = r2wc(ClassContainer, {
  props: {
    apiInfoElement: 'string',
    apiInfo: 'json',
    uiSchema: 'json',
    connection: 'function',
    websocketUrl: 'string',
    topic: 'string',
    className: 'string',
    skipDefaultResponseHandler: 'boolean',
    skipDefaultResponseHandlerCheck: 'function',
    skipDefaultErrorHandler: 'boolean',
    skipDefaultErrorHandlerCheck: 'function',
    skipDefaultProgressHandler: 'boolean',
    skipDefaultProgressHandlerCheck: 'function',
  },
  events: {
    onResponse: {},
    onError: {},
    onProgress: {},
  },
});

const WebModuleContainer = r2wc(ModuleContainer, {
  props: {
    apiInfoElement: 'string',
    apiInfo: 'json',
    member: 'string',
    connection: 'function',
    websocketUrl: 'string',
    topic: 'string',
    skipDefaultResponseHandler: 'boolean',
    skipDefaultResponseHandlerCheck: 'function',
    skipDefaultErrorHandler: 'boolean',
    skipDefaultErrorHandlerCheck: 'function',
    skipDefaultProgressHandler: 'boolean',
    skipDefaultProgressHandlerCheck: 'function',
  },
  events: {
    onResponse: {},
    onError: {},
    onProgress: {},
  },
});

customElements.define('dasf-function', WebFunctionContainer);
customElements.define('dasf-class', WebClassContainer);
customElements.define('dasf-module', WebModuleContainer);

export { FunctionContainer, ClassContainer, ModuleContainer };
export { getConnection } from './resources/connection';

export type { FunctionContainerOptions } from './resources/FunctionContainerOptions';
export type { ClassContainerOptions } from './resources/ClassContainerOptions';
export type { ConnectionOptions } from './resources/connection';
