// SPDX-FileCopyrightText: 2025 Helmholtz-Zentrum hereon GmbH
//
// SPDX-License-Identifier: Apache-2.0

import { render } from '@testing-library/react';
import { describe, expect, it, vi } from 'vitest';

import FunctionContainer from '../src/components/FunctionContainer';
import { DASFConnection, WebsocketUrlBuilder } from '@dasf/dasf-messaging';

function createConnection(uri?: string): DASFConnection {
  const websocketUrl = uri
    ? uri
    : import.meta.env.VITE_WEBSOCKET_URL || 'ws://localhost:8080/ws';
  const topic = 'mytesttopic';
  return new DASFConnection(new WebsocketUrlBuilder(websocketUrl, topic));
}

describe('FunctionContainer', () => {
  it('test FunctionContainer submission', async () => {
    const connection = createConnection();

    const result = [];

    const handleResponse = (response) => {
      result.push(response);
    };

    const container = render(
      <FunctionContainer
        connection={connection}
        functionName="test_function"
        onResponse={handleResponse}
      />,
    );
    await vi.waitFor(() => container.getByRole('button'), {
      timeout: 3000,
      interval: 20,
    });
    const submitButton = container.getByRole('button');
    expect(submitButton.innerHTML).toBe('Submit');
    await submitButton.click();

    await vi.waitFor(
      () => {
        if (result.length != 1) throw Error('No response yet');
      },
      {
        timeout: 3000,
        interval: 20,
      },
    );
    expect(result[0]).toEqual(1);
  });
});
