// SPDX-FileCopyrightText: 2025 Helmholtz-Zentrum hereon GmbH
//
// SPDX-License-Identifier: Apache-2.0

import { render } from '@testing-library/react';
import { describe, expect, it } from 'vitest';

import FunctionForm from '../src/components/FunctionForm';

describe('FunctionForm', () => {
  it('test FunctionForm initialization', async () => {
    const schema = {
      description: 'Find R and B values for an ICON grid.',
      properties: {
        func_name: {
          const: 'icon_rb',
          description: "The name of the function. Must be 'icon_rb'",
          enum: ['icon_rb'],
          title: 'Func Name',
          type: 'string',
        },
        delta: {
          description: 'The target grid width in kilometer.',
          exclusiveMinimum: 0.0,
          title: 'Delta',
          type: 'number',
        },
      },
      required: ['func_name', 'delta'],
      title: 'FuncIconRb',
      type: 'object',
    };
    const form = render(<FunctionForm schema={schema} />);
    expect(form.getByRole('button').innerHTML).toBe('Submit');
    expect(form.getByRole('spinbutton').id).toBe('root_delta');
  });
});
