// SPDX-FileCopyrightText: 2025 Helmholtz-Zentrum hereon GmbH
//
// SPDX-License-Identifier: Apache-2.0

import { render } from '@testing-library/react';
import { describe, expect, it, vi } from 'vitest';

import ModuleContainer from '../src/components/ModuleContainer';
import { DASFConnection, WebsocketUrlBuilder } from '@dasf/dasf-messaging';

function createConnection(uri?: string): DASFConnection {
  const websocketUrl = uri
    ? uri
    : import.meta.env.VITE_WEBSOCKET_URL || 'ws://localhost:8080/ws';
  const topic = 'mytesttopic';
  return new DASFConnection(new WebsocketUrlBuilder(websocketUrl, topic));
}

describe('ModuleContainer', () => {
  it('test ModuleContainer submission', async () => {
    const connection = createConnection();

    const result = [];

    const handleResponse = (response) => {
      result.push(response);
    };

    const container = render(
      <ModuleContainer
        connection={connection}
        member="test_function"
        onResponse={handleResponse}
      />,
    );
    await vi.waitFor(() => container.getAllByRole('button')[1], {
      timeout: 3000,
      interval: 20,
    });
    // submit button of test_function is at position 1
    const submitButton = container.getAllByRole('button')[1];
    expect(submitButton.innerHTML).toBe('Submit');
    await submitButton.click();

    await vi.waitFor(
      () => {
        if (result.length != 1) throw Error('No response yet');
      },
      {
        timeout: 3000,
        interval: 20,
      },
    );
    expect(result[0]).toEqual(1);
  });
});
