// SPDX-FileCopyrightText: 2024 Helmholtz-Zentrum hereon GmbH
// SPDX-FileCopyrightText: 2025 Helmholtz-Zentrum hereon GmbH
//
// SPDX-License-Identifier: CC0-1.0
// SPDX-License-Identifier: CC0-1.0

import { fileURLToPath } from 'node:url';
import { mergeConfig, defineConfig, configDefaults } from 'vitest/config';
import viteConfig from './vite.config';

export default mergeConfig(
  viteConfig,
  defineConfig({
    test: {
      environment: 'jsdom',
      globals: true,
      setupFiles: './tests/setup.js',
      exclude: [...configDefaults.exclude, 'e2e/**'],
      root: fileURLToPath(new URL('./', import.meta.url)),
      coverage: {
        reportsDirectory: './coverage/reports',
        exclude: [
          ...configDefaults.exclude,
          'tests/**',
          '*.cjs',
          './src/main.tsx',
        ],
        reporter: [
          'html',
          'clover',
          'json',
          'lcov',
          'text',
          'text-summary',
          'cobertura',
          'json-summary',
        ],
      },
    },
  }),
);
